@@ -22,7 +22,7 @@ except ImportError:
 
 from BFEE2 import doc
 
-VERSION = 'BFEEstimator v2.1.3'
+VERSION = 'BFEEstimator v2.1.3.1'
 
 class mainSettings(QWidget):
     """settings in the menubar
@@ -999,7 +999,7 @@ class mainUI(QMainWindow):
         self.alchemicalForceConstants.setLayout(self.alchemicalFCLayout)
 
         # alchemical restraint centers
-        self.alchemicalRestraintCenters = QGroupBox('Restraint centers (in Colvars unit):')
+        self.alchemicalRestraintCenters = QGroupBox('Restraint centers (in Colvars unit) and temperature:')
 
         # all widgets
         self.alchemicalRCLayout = QHBoxLayout()
@@ -1009,6 +1009,8 @@ class mainUI(QMainWindow):
         self.alchemicalRCthetaLineEdit = QLineEdit('90')
         self.alchemicalRCRLabel = QLabel('r: ')
         self.alchemicalRCRLineEdit = QLineEdit('8')
+        self.alchemicalPostTemperatureLabel = QLabel('temperature:')
+        self.alchemicalPostTemperatureLineEdit = QLineEdit('300')
 
         self.alchemicalRCLayout.addWidget(self.alchemicalRCThetaLabel)
         self.alchemicalRCLayout.addWidget(self.alchemicalRCThetaLineEdit)
@@ -1016,6 +1018,8 @@ class mainUI(QMainWindow):
         self.alchemicalRCLayout.addWidget(self.alchemicalRCthetaLineEdit)
         self.alchemicalRCLayout.addWidget(self.alchemicalRCRLabel)
         self.alchemicalRCLayout.addWidget(self.alchemicalRCRLineEdit)
+        self.alchemicalRCLayout.addWidget(self.alchemicalPostTemperatureLabel)
+        self.alchemicalRCLayout.addWidget(self.alchemicalPostTemperatureLineEdit)
 
         self.alchemicalRestraintCenters.setLayout(self.alchemicalRCLayout)
 
@@ -1131,14 +1135,14 @@ class mainUI(QMainWindow):
         """
 
         with pkg_resources.path(doc, 'Doc.pdf') as docFile:
-            webbrowser.open(docFile)
+            webbrowser.open(str(docFile))
 
     def _openPythonAPIFile(self):
         """open Python API Documentation file
         """
 
         with pkg_resources.path(doc, 'PythonAPI.pdf') as pythonAPIFile:
-            webbrowser.open(pythonAPIFile)
+            webbrowser.open(str(pythonAPIFile))
 
     def _showAboutBox(self):
         """the about message box
@@ -1151,14 +1155,23 @@ class mainUI(QMainWindow):
             QMessageBox.about(
                 self,
                 'About',
-                f"\
-           {VERSION}\n\n \
-Auther: Haohao Fu (fhh2626@gmail.com)\n\n\
-This software is under the GPLv3 license.\n\n\
-Contact Wensheng Cai (wscai@nankai.edu.cn)\n\
-and Chris Chipot (chipot@ks.uiuc.edu) for\n\
-further copyright information.", 
-                            )
+                f'<center><b>{VERSION}</b></center><br>'+r'''
+                Binding free energy estimator (BFEE) is a python-based software
+                that automates absolute binding free energy calculations through
+                either the alchemical or geometric route by molecular dynamics
+                simulations.<br>
+                <b>Authors:</b><br>
+                Haohao Fu (<a href="mailto:fhh2626@gmail.com">fhh2626@gmail.com</a>)<br>
+                Haochuan Chen (<a href="mailto:summersnow9403@gmail.com">summersnow9403@gmail.com</a>)<br>
+                <b>License:</b><br>
+                BFEE2 is free software: you can redistribute it and/or modify it
+                under the terms of the GNU General Public License as published by
+                the Free Software Foundation, either version 3 of the License, or
+                (at your option) any later version.<br>
+                <b>Contact</b> Wensheng Cai (<a href="mailto:wscai@nankai.edu.cn">wscai@nankai.edu.cn</a>)
+                and Chris Chipot (<a href="mailto:chipot@ks.uiuc.edu">chipot@ks.uiuc.edu</a>)
+                for further copyright information.
+                ''')
         return f
 
     def _showGeometricResults(self, unit):
@@ -1169,7 +1182,7 @@ further copyright information.",
                 unit (string): 'namd' or 'gromacs' '''
         
         pTreat = postTreatment.postTreatment(
-            float(self.temperatureLineEdit.text()), unit, 'geometric')
+            float(self.postTemperatureLineEdit.text()), unit, 'geometric')
             
         pmfs = [
                     self.rmsdBoundLineEdit.text(), 
@@ -1235,7 +1248,7 @@ Standard Binding Free Energy:\n\
         """
         
         pTreat = postTreatment.postTreatment(
-            float(self.temperatureLineEdit.text()), unit, 'geometric')
+            float(self.alchemicalPostTemperatureLineEdit.text()), unit, 'geometric')
         
         # alchemical outputs
         files = [
@@ -1358,9 +1371,7 @@ Standard Binding Free Energy:\n\
 
             if self.preTreatmentMainTabs.currentIndex() == 0:
                 # force fields
-                forceFieldFiles = []
-                for item in self.forceFieldFilesBox.findItems('*', QtCore.Qt.MatchWildcard):
-                    forceFieldFiles.append(item.text())
+                forceFieldFiles = [self.forceFieldFilesBox.item(i).text() for i in range(self.forceFieldFilesBox.count())]
 
                 # NAMD files
                 for item in [self.psfLineEdit.text(), self.coorLineEdit.text()] + forceFieldFiles:
@@ -1637,9 +1648,7 @@ Unknown error!'
 
             path, _ = QFileDialog.getSaveFileName(None, 'Set the name of merged PMF')
 
-            pmfs = []
-            for item in self.mergePmfBox.findItems('*', QtCore.Qt.MatchWildcard):
-                pmfs.append(ploter.readPMF(item.text()))
+            pmfs = [ploter.readPMF(self.mergePmfBox.item(i).text()) for i in range(self.mergePmfBox.count())]
 
             mergedPMF = ploter.mergePMF(pmfs)
             ploter.writePMF(path, mergedPMF)
@@ -1658,9 +1667,7 @@ Unknown error!'
                 QMessageBox.warning(self, 'Warning', f'Warning, no PMF selected!')
                 return
 
-            pmfs = []
-            for item in self.plotPmfBox.findItems('*', QtCore.Qt.MatchWildcard):
-                pmfs.append(ploter.readPMF(item.text()))
+            pmfs = [ploter.readPMF(self.plotPmfBox.item(i).text()) for i in range(self.plotPmfBox.count())]
 
             mergedPMF = ploter.mergePMF(pmfs)
             ploter.plotPMF(mergedPMF)
